Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(115)

Unified Diff: chrome/browser/aeropeek_manager.cc

Issue 996003: Adds a command-line option that disables AeroPeek.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/common/chrome_switches.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/aeropeek_manager.cc
===================================================================
--- chrome/browser/aeropeek_manager.cc (revision 41921)
+++ chrome/browser/aeropeek_manager.cc (working copy)
@@ -1018,10 +1018,15 @@
// static
bool AeroPeekManager::Enabled() {
// We enable our custom AeroPeek only when:
- // * Chrome is running on Windows 7, and
- // * Chrome is not lauched in the application mode.
- return win_util::GetWinVersion() >= win_util::WINVERSION_WIN7 &&
- !CommandLine::ForCurrentProcess()->HasSwitch(switches::kApp);
+ // * Chrome is running on Windows 7,
+ // * Chrome is not lauched in the application mode, and
+ // * Aero is enabled.
+ if (win_util::GetWinVersion() < win_util::WINVERSION_WIN7 ||
+ CommandLine::ForCurrentProcess()->HasSwitch(switches::kDisableAeroPeek) ||
+ CommandLine::ForCurrentProcess()->HasSwitch(switches::kApp))
+ return false;
+
+ return win_util::ShouldUseVistaFrame();
}
void AeroPeekManager::DeleteAeroPeekWindow(int tab_id) {
« no previous file with comments | « no previous file | chrome/common/chrome_switches.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698